==> typescript_1.4.orig.tar.gz: TypeScript-1.4/tests/baselines/reference/untypedFunctionCallsWithTypeParameters1.js <==
//// [untypedFunctionCallsWithTypeParameters1.ts]
// none of these function calls should be allowed
var x = function () { return; };
var r1 = x<number>();
var y: any = x;
var r2 = y<string>();

var c: Function;
var r3 = c<number>(); // should be an error

class C implements Function {
    prototype = null;
    length = 1;
    arguments = null;
    caller = () => { };
}

var c2: C;
var r4 = c2<number>(); // should be an error

class C2 extends Function { } // error
var c3: C2;
var r5 = c3<number>(); // error

interface I {
    (number): number;
}
var z: I;
var r6 = z<string>(1); // error

interface callable2<T> {
    (a: T): T;
}

var c4: callable2<number>;
c4<number>(1);
interface callable3<T> {
    (a: T): T;
}

var c5: callable3<number>;
c5<string>(1); // error



//// [untypedFunctionCallsWithTypeParameters1.js]
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
// none of these function calls should be allowed
var x = function () {
    return;
};
var r1 = x();
var y = x;
var r2 = y();
var c;
var r3 = c(); // should be an error
var C = (function () {
    function C() {
        this.prototype = null;
        this.length = 1;
        this.arguments = null;
        this.caller = function () {
        };
    }
    return C;
})();
var c2;
var r4 = c2(); // should be an error
var C2 = (function (_super) {
    __extends(C2, _super);
    function C2() {
        _super.apply(this, arguments);
    }
    return C2;
})(Function); // error
var c3;
var r5 = c3(); // error
var z;
var r6 = z(1); // error
var c4;
c4(1);
var c5;
c5(1); // error

==> typescript_1.7.5.orig.tar.gz: TypeScript-1.7.5/tests/baselines/reference/untypedFunctionCallsWithTypeParameters1.js <==
//// [untypedFunctionCallsWithTypeParameters1.ts]
// none of these function calls should be allowed
var x = function () { return; };
var r1 = x<number>();
var y: any = x;
var r2 = y<string>();

var c: Function;
var r3 = c<number>(); // should be an error

class C implements Function {
    prototype = null;
    length = 1;
    arguments = null;
    caller = () => { };
}

var c2: C;
var r4 = c2<number>(); // should be an error

class C2 extends Function { } // error
var c3: C2;
var r5 = c3<number>(); // error

interface I {
    (number): number;
}
var z: I;
var r6 = z<string>(1); // error

interface callable2<T> {
    (a: T): T;
}

var c4: callable2<number>;
c4<number>(1);
interface callable3<T> {
    (a: T): T;
}

var c5: callable3<number>;
c5<string>(1); // error



//// [untypedFunctionCallsWithTypeParameters1.js]
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
// none of these function calls should be allowed
var x = function () { return; };
var r1 = x();
var y = x;
var r2 = y();
var c;
var r3 = c(); // should be an error
var C = (function () {
    function C() {
        this.prototype = null;
        this.length = 1;
        this.arguments = null;
        this.caller = function () { };
    }
    return C;
})();
var c2;
var r4 = c2(); // should be an error
var C2 = (function (_super) {
    __extends(C2, _super);
    function C2() {
        _super.apply(this, arguments);
    }
    return C2;
})(Function); // error
var c3;
var r5 = c3(); // error
var z;
var r6 = z(1); // error
var c4;
c4(1);
var c5;
c5(1); // error
